@@ -8,7 +8,7 @@ test_that("x must be a named list", {
 test_that("output is a vector of appropriately name elements", {
   ae1 <- average_endpoints(list(ecx4param = ecx4param, nec4param = nec4param))
   expect_equal(length(ae1), 3)
-  expect_equal(names(ae1), c("50%", "2.5%", "97.5%"))
+  expect_equal(names(ae1), c("Q50", "Q2.5", "Q97.5"))
 })
 
 test_that("xform passes correctly", {
@@ -26,6 +26,6 @@ test_that("posterior passes correctly", {
 
 test_that("prob_vals passes correctly", {
   ae4 <- average_endpoints(list(ecx4param = ecx4param, nec4param = nec4param),
-                           prob_vals = c(0.3, 0.5, 0.7))
-  expect_equal(names(ae4), c("30%", "50%", "70%"))
+                           prob_vals = c(0.5, 0.3, 0.7))
+  expect_equal(names(ae4), c("Q50", "Q30", "Q70"))
 })
